==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/inc/lang/fo/lang.php <==
<?php
/**
 * faroese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Poul J. Clementsen <poul@diku.dk>
 * @author Einar Petersen <einar.petersen@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = 'Vanligt gásareygað byrjan';
$lang['doublequoteclosing']    = 'Vanligt gásareygað endi';
$lang['singlequoteopening']    = 'Einstakt gásareygað byrjan';
$lang['singlequoteclosing']    = 'Einstakt gásareygað endi';
$lang['apostrophe']            = 'Apostroff';
$lang['btn_edit']              = 'Rætta hetta skjal';
$lang['btn_source']            = 'Vís keldu';
$lang['btn_show']              = 'Vís skjal';
$lang['btn_create']            = 'Býrja uppá hetta skjal';
$lang['btn_search']            = 'Leita';
$lang['btn_save']              = 'Goym';
$lang['btn_preview']           = 'Forskoðan';
$lang['btn_top']               = 'Aftur til toppin';
$lang['btn_newer']             = '<< undan síða';
$lang['btn_older']             = 'næsta síðe >>';
$lang['btn_revs']              = 'Gamlar útgávur';
$lang['btn_recent']            = 'Nýggj broyting';
$lang['btn_upload']            = 'Legg fílu upp';
$lang['btn_cancel']            = 'Angra';
$lang['btn_index']             = 'Evnisyvirlit';
$lang['btn_secedit']           = 'Rætta';
$lang['btn_login']             = 'Rita inn';
$lang['btn_logout']            = 'Rita út';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Dagfør';
$lang['btn_delete']            = 'Strika';
$lang['btn_back']              = 'Aftur';
$lang['btn_backlink']          = 'Ávísingar afturúr';
$lang['btn_backtomedia']       = 'Aftur til val av miðlafílu';
$lang['btn_subscribe']         = 'Tilmelda broytingar';
$lang['btn_profile']           = 'Dagføra vangamynd';
$lang['btn_reset']             = 'Nullstilla';
$lang['btn_resendpwd']         = 'Send nýtt loyniorð';
$lang['btn_draft']             = 'Broyt kladdu';
$lang['btn_recover']           = 'Endurbygg kladdu';
$lang['btn_draftdel']          = 'Sletta';
$lang['btn_revert']            = 'Endurbygg';
$lang['btn_register']          = 'Melda til';
$lang['loggedinas']            = 'Ritavur inn sum';
$lang['user']                  = 'Brúkaranavn';
$lang['pass']                  = 'Loyniorð';
$lang['newpass']               = 'Nýtt loyniorð';
$lang['oldpass']               = 'Vátta núverandi loyniorð';
$lang['passchk']               = 'Endurtak nýtt loyniorð';
$lang['remember']              = 'Minst til loyniorðið hjá mær';
$lang['fullname']              = 'Navn';
$lang['email']                 = 'T-postur';
$lang['profile']               = 'Brúkara vangamynd';
$lang['badlogin']              = 'Skeivt brúkaranavn ella loyniorð.';
$lang['minoredit']             = 'Smærri broytingar';
$lang['draftdate']             = 'Goym kladdu sett frá';
$lang['nosecedit']             = 'Hendan síðan var broytt undir tilevnan, brotið var ikki rætt dagfest, heintaði fulla síðu í staðin';
$lang['regmissing']            = 'Tú skalt fylla út øll øki.';
$lang['reguexists']            = 'Hetta brúkaranavn er upptiki.';
$lang['regsuccess']            = 'Tú ert nú stovnavur sum brúkari. Títt loyniorð verður sent til tín í einum T-posti.';
$lang['regsuccess2']           = 'Tú ert nú stovnavur sum brúkari.';
$lang['regmailfail']           = 'Títt loyniorð bleiv ikki sent. Fá vinarliga samband við administratorin.';
$lang['regbadmail']            = 'T-post adressan er ógildig. Fá vinarliga samband við administratorin, um tú heldur at hetta er eitt brek.';
$lang['regbadpass']            = 'Bæði loyniorðini eru ikki eins, royn vinarliga umaftur.';
$lang['regpwmail']             = 'Títt DokuWiki loyniorð';
$lang['reghere']               = 'Upprætta eina DokuWiki-konto her';
$lang['profna']                = 'Tað er ikki møguligt at broyta tína vangamynd í hesu wiki';
$lang['profnochange']          = 'Ongar broytingar, onki tillaga.';
$lang['profnoempty']           = 'Tómt navn ella t-post adressa er ikki loyvt.';
$lang['profchanged']           = 'Brúkara vangamynd dagført rætt.';
$lang['pwdforget']             = 'Gloymt títt loyniorð? Fá eitt nýtt';
$lang['resendna']              = 'Tað er ikki møguligt at fá sent nýtt loyniorð við hesu wiki.';
$lang['resendpwd']             = 'Send nýtt loyniorð til';
$lang['resendpwdmissing']      = 'Tú skal filla út øll økir.';
$lang['resendpwdnouser']       = 'Vit kunna ikki finna hendan brúkara í okkara dátagrunni.';
$lang['resendpwdbadauth']      = 'Hald til góðar, hendan góðkenningar kodan er ikki gildug. Kanna eftir at tú nýtti tað fulfíggjaðu góðkenningarleinkjuna';
$lang['resendpwdconfirm']      = 'Ein góðkenningarleinkja er send við e-posti';
$lang['resendpwdsuccess']      = 'Títt nýggja loyniorð er sent við t-posti.';
$lang['license']               = 'Um ikki annað er tilskilað, so er tilfar á hesari wiki loyvt margfaldað undir fylgjandi treytum:';
$lang['licenseok']             = 'Legg til merkis: Við at dagføra hesa síðu samtykkir tú at loyva margfalding av tilfarinum undir fylgjandi treytum:';
$lang['searchmedia']           = 'Leita eftir fíl navn:';
$lang['searchmedia_in']        = 'Leita í %s';
$lang['txt_upload']            = 'Vel tí fílu sum skal leggjast upp';
$lang['txt_filename']          = 'Sláa inn wikinavn (valfrítt)';
$lang['txt_overwrt']           = 'Yvurskriva verandi fílu';
$lang['lockedby']              = 'Fyribils læst av';
$lang['lockexpire']            = 'Lásið ferð úr gildi kl.';
$lang['js']['willexpire']            = 'Títt lás á hetta skjalið ferð úr gildi um ein minnutt.\nTrýst á Forskoðan-knappin fyri at sleppa undan trupulleikum.';
$lang['js']['notsavedyet']     = 'Tað eru gjørdar broytingar í skjalinum, um tú haldur fram vilja broytingar fara fyri skeytið.
Ynskir tú at halda fram?';
$lang['js']['searchmedia']     = 'Leita eftir dátufílum';
$lang['js']['mediasize']       = 'Mynda stødd';
$lang['js']['mediatarget']     = 'Leinkja til';
$lang['js']['mediaclose']      = 'Læt aftur';
$lang['js']['mediainsert']     = 'Set inn';
$lang['js']['mediadisplayimg'] = 'Vís myndina';
$lang['js']['mediadisplaylnk'] = 'Vís bert leinkjuna';
$lang['js']['nosmblinks']      = 'Ávísingar til Windows shares virka bert í Microsoft Internet Explorer.
Tú kanst enn avrita og sata inn slóðina.';
$lang['js']['del_confirm']     = 'Strika post(ar)?';
$lang['rssfailed']             = 'Eitt brek koma fyri tá roynt var at fáa: ';
$lang['nothingfound']          = 'Leiting gav onki úrslit.';
$lang['mediaselect']           = 'Vel miðlafílu';
$lang['fileupload']            = 'Legg miðla fílu upp';
$lang['uploadsucc']            = 'Upp legg av fílu var væl eydna';
$lang['uploadfail']            = 'Brek við upp legg av fílu. Tað er møguliga trupuleikar við rættindunum';
$lang['uploadwrong']           = 'Upp legg av fílu víst burtur. Fíluslag er ikki loyvt';
$lang['uploadexist']           = 'Fílan er longu til.';
$lang['deletesucc']            = 'Fílan "%s" er nú strika.';
$lang['deletefail']            = '"%s" kundi ikki strikast - kanna rættindini.';
$lang['mediainuse']            = 'Fíla "%s" er ikki strika - hen verður enn nýtt.';
$lang['namespaces']            = 'Navnarúm';
$lang['mediafiles']            = 'Atkomandi fílur í';
$lang['reference']             = 'Ávísing til';
$lang['ref_inuse']             = 'Fílan kan ikki strikast, síðan hon enn verður nýtt á fylgjandi síðum:';
$lang['ref_hidden']            = 'Nakrar ávísingar eru í skjølum sum tú ikki hevur lesi rættindi til';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Samsvarandi skjøl';
$lang['toc']                   = 'Innihaldsyvirlit';
$lang['current']               = 'núverandi';
$lang['yours']                 = 'Tín útgáva';
$lang['diff']                  = 'vís broytingar í mun til núverandi útgávu';
$lang['line']                  = 'Linja';
$lang['breadcrumb']            = 'Leið';
$lang['youarehere']            = 'Tú ert her';
$lang['lastmod']               = 'Seinast broytt';
$lang['by']                    = 'av';
$lang['deleted']               = 'strika';
$lang['created']               = 'stovna';
$lang['restored']              = 'gomul útgáva endurstovna';
$lang['summary']               = 'Samandráttur';
$lang['mail_newpage']          = 'skjal skoyta uppí:';
$lang['mail_changed']          = 'skjal broytt:';
$lang['qb_bold']               = 'Feit';
$lang['qb_italic']             = 'Skák';
$lang['qb_underl']             = 'Undurstrika';
$lang['qb_code']               = 'Skrivimaskinu tekstur';
$lang['qb_strike']             = 'Gjøgnumstrika';
$lang['qb_h1']                 = 'Stig 1 yvirskrift';
$lang['qb_h2']                 = 'Stig 2 yvirskrift';
$lang['qb_h3']                 = 'Stig 3 yvirskrift';
$lang['qb_h4']                 = 'Stig 4 yvirskrift';
$lang['qb_h5']                 = 'Stig 5 yvirskrift';
$lang['qb_link']               = 'Innanhýsis slóð';
$lang['qb_extlink']            = 'Útvortis slóð';
$lang['qb_hr']                 = 'Vatnrætt linja';
$lang['qb_ol']                 = 'Talmerktur listi';
$lang['qb_ul']                 = 'Ótalmerktur listi';
$lang['qb_media']              = 'Leggja myndir og aðrar fílur afturat';
$lang['qb_sig']                = 'Set inn undirskrift';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Sertekn';
$lang['admin_register']        = 'Upprætta nýggjan brúkara';
$lang['metaedit']              = 'Rætta metadáta';
$lang['metasaveerr']           = 'Brek við skriving av metadáta';
$lang['metasaveok']            = 'Metadáta goymt';
$lang['img_backto']            = 'Aftur til';
$lang['img_title']             = 'Heitið';
$lang['img_caption']           = 'Myndatekstur';
$lang['img_date']              = 'Dato';
$lang['img_fname']             = 'Fílunavn';
$lang['img_fsize']             = 'Stødd';
$lang['img_artist']            = 'Myndafólk';
$lang['img_copyr']             = 'Upphavsrættur';
$lang['img_format']            = 'Snið';
$lang['img_camera']            = 'Fototól';
$lang['img_keywords']          = 'Evnisorð';
$lang['authmodfailed']         = 'Brek við validering av brúkarasamansetingv. Fá samband við umboðsstjóran á hesi wiki.';
$lang['authtempfail']          = 'Validering av brúkara virkar fyribils ikki. Um hetta er varandi, fá so samband við umboðsstjóran á hesi wiki.';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/inc/lang/fo/lang.php <==
<?php
/**
 * faroese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Poul J. Clementsen <poul@diku.dk>
 * @author Einar Petersen <einar.petersen@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = 'Vanligt gásareygað byrjan';
$lang['doublequoteclosing']    = 'Vanligt gásareygað endi';
$lang['singlequoteopening']    = 'Einstakt gásareygað byrjan';
$lang['singlequoteclosing']    = 'Einstakt gásareygað endi';
$lang['apostrophe']            = 'Apostroff';
$lang['btn_edit']              = 'Rætta hetta skjal';
$lang['btn_source']            = 'Vís keldu';
$lang['btn_show']              = 'Vís skjal';
$lang['btn_create']            = 'Býrja uppá hetta skjal';
$lang['btn_search']            = 'Leita';
$lang['btn_save']              = 'Goym';
$lang['btn_preview']           = 'Forskoðan';
$lang['btn_top']               = 'Aftur til toppin';
$lang['btn_newer']             = '<< undan síða';
$lang['btn_older']             = 'næsta síðe >>';
$lang['btn_revs']              = 'Gamlar útgávur';
$lang['btn_recent']            = 'Nýggj broyting';
$lang['btn_upload']            = 'Legg fílu upp';
$lang['btn_cancel']            = 'Angra';
$lang['btn_index']             = 'Evnisyvirlit';
$lang['btn_secedit']           = 'Rætta';
$lang['btn_login']             = 'Rita inn';
$lang['btn_logout']            = 'Rita út';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Dagfør';
$lang['btn_delete']            = 'Strika';
$lang['btn_back']              = 'Aftur';
$lang['btn_backlink']          = 'Ávísingar afturúr';
$lang['btn_backtomedia']       = 'Aftur til val av miðlafílu';
$lang['btn_subscribe']         = 'Tilmelda broytingar';
$lang['btn_profile']           = 'Dagføra vangamynd';
$lang['btn_reset']             = 'Nullstilla';
$lang['btn_draft']             = 'Broyt kladdu';
$lang['btn_recover']           = 'Endurbygg kladdu';
$lang['btn_draftdel']          = 'Sletta';
$lang['btn_revert']            = 'Endurbygg';
$lang['btn_register']          = 'Melda til';
$lang['loggedinas']            = 'Ritavur inn sum';
$lang['user']                  = 'Brúkaranavn';
$lang['pass']                  = 'Loyniorð';
$lang['newpass']               = 'Nýtt loyniorð';
$lang['oldpass']               = 'Vátta núverandi loyniorð';
$lang['passchk']               = 'Endurtak nýtt loyniorð';
$lang['remember']              = 'Minst til loyniorðið hjá mær';
$lang['fullname']              = 'Navn';
$lang['email']                 = 'T-postur';
$lang['profile']               = 'Brúkara vangamynd';
$lang['badlogin']              = 'Skeivt brúkaranavn ella loyniorð.';
$lang['minoredit']             = 'Smærri broytingar';
$lang['draftdate']             = 'Goym kladdu sett frá';
$lang['nosecedit']             = 'Hendan síðan var broytt undir tilevnan, brotið var ikki rætt dagfest, heintaði fulla síðu í staðin';
$lang['regmissing']            = 'Tú skalt fylla út øll øki.';
$lang['reguexists']            = 'Hetta brúkaranavn er upptiki.';
$lang['regsuccess']            = 'Tú ert nú stovnavur sum brúkari. Títt loyniorð verður sent til tín í einum T-posti.';
$lang['regsuccess2']           = 'Tú ert nú stovnavur sum brúkari.';
$lang['regmailfail']           = 'Títt loyniorð bleiv ikki sent. Fá vinarliga samband við administratorin.';
$lang['regbadmail']            = 'T-post adressan er ógildig. Fá vinarliga samband við administratorin, um tú heldur at hetta er eitt brek.';
$lang['regbadpass']            = 'Bæði loyniorðini eru ikki eins, royn vinarliga umaftur.';
$lang['regpwmail']             = 'Títt DokuWiki loyniorð';
$lang['reghere']               = 'Upprætta eina DokuWiki-konto her';
$lang['profna']                = 'Tað er ikki møguligt at broyta tína vangamynd í hesu wiki';
$lang['profnochange']          = 'Ongar broytingar, onki tillaga.';
$lang['profnoempty']           = 'Tómt navn ella t-post adressa er ikki loyvt.';
$lang['profchanged']           = 'Brúkara vangamynd dagført rætt.';
$lang['pwdforget']             = 'Gloymt títt loyniorð? Fá eitt nýtt';
$lang['resendna']              = 'Tað er ikki møguligt at fá sent nýtt loyniorð við hesu wiki.';
$lang['resendpwdmissing']      = 'Tú skal filla út øll økir.';
$lang['resendpwdnouser']       = 'Vit kunna ikki finna hendan brúkara í okkara dátagrunni.';
$lang['resendpwdbadauth']      = 'Hald til góðar, hendan góðkenningar kodan er ikki gildug. Kanna eftir at tú nýtti tað fulfíggjaðu góðkenningarleinkjuna';
$lang['resendpwdconfirm']      = 'Ein góðkenningarleinkja er send við e-posti';
$lang['resendpwdsuccess']      = 'Títt nýggja loyniorð er sent við t-posti.';
$lang['license']               = 'Um ikki annað er tilskilað, so er tilfar á hesari wiki loyvt margfaldað undir fylgjandi treytum:';
$lang['licenseok']             = 'Legg til merkis: Við at dagføra hesa síðu samtykkir tú at loyva margfalding av tilfarinum undir fylgjandi treytum:';
$lang['searchmedia']           = 'Leita eftir fíl navn:';
$lang['searchmedia_in']        = 'Leita í %s';
$lang['txt_upload']            = 'Vel tí fílu sum skal leggjast upp';
$lang['txt_filename']          = 'Sláa inn wikinavn (valfrítt)';
$lang['txt_overwrt']           = 'Yvurskriva verandi fílu';
$lang['lockedby']              = 'Fyribils læst av';
$lang['lockexpire']            = 'Lásið ferð úr gildi kl.';
$lang['js']['willexpire']            = 'Títt lás á hetta skjalið ferð úr gildi um ein minnutt.\nTrýst á Forskoðan-knappin fyri at sleppa undan trupulleikum.';
$lang['js']['notsavedyet']     = 'Tað eru gjørdar broytingar í skjalinum, um tú haldur fram vilja broytingar fara fyri skeytið.
Ynskir tú at halda fram?';
$lang['js']['searchmedia']     = 'Leita eftir dátufílum';
$lang['js']['mediasize']       = 'Mynda stødd';
$lang['js']['mediatarget']     = 'Leinkja til';
$lang['js']['mediaclose']      = 'Læt aftur';
$lang['js']['mediainsert']     = 'Set inn';
$lang['js']['mediadisplayimg'] = 'Vís myndina';
$lang['js']['mediadisplaylnk'] = 'Vís bert leinkjuna';
$lang['js']['nosmblinks']      = 'Ávísingar til Windows shares virka bert í Microsoft Internet Explorer.
Tú kanst enn avrita og sata inn slóðina.';
$lang['js']['del_confirm']     = 'Strika post(ar)?';
$lang['rssfailed']             = 'Eitt brek koma fyri tá roynt var at fáa: ';
$lang['nothingfound']          = 'Leiting gav onki úrslit.';
$lang['mediaselect']           = 'Vel miðlafílu';
$lang['fileupload']            = 'Legg miðla fílu upp';
$lang['uploadsucc']            = 'Upp legg av fílu var væl eydna';
$lang['uploadfail']            = 'Brek við upp legg av fílu. Tað er møguliga trupuleikar við rættindunum';
$lang['uploadwrong']           = 'Upp legg av fílu víst burtur. Fíluslag er ikki loyvt';
$lang['uploadexist']           = 'Fílan er longu til.';
$lang['deletesucc']            = 'Fílan "%s" er nú strika.';
$lang['deletefail']            = '"%s" kundi ikki strikast - kanna rættindini.';
$lang['mediainuse']            = 'Fíla "%s" er ikki strika - hen verður enn nýtt.';
$lang['namespaces']            = 'Navnarúm';
$lang['mediafiles']            = 'Atkomandi fílur í';
$lang['reference']             = 'Ávísing til';
$lang['ref_inuse']             = 'Fílan kan ikki strikast, síðan hon enn verður nýtt á fylgjandi síðum:';
$lang['ref_hidden']            = 'Nakrar ávísingar eru í skjølum sum tú ikki hevur lesi rættindi til';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Samsvarandi skjøl';
$lang['toc']                   = 'Innihaldsyvirlit';
$lang['current']               = 'núverandi';
$lang['yours']                 = 'Tín útgáva';
$lang['diff']                  = 'vís broytingar í mun til núverandi útgávu';
$lang['line']                  = 'Linja';
$lang['breadcrumb']            = 'Leið';
$lang['youarehere']            = 'Tú ert her';
$lang['lastmod']               = 'Seinast broytt';
$lang['by']                    = 'av';
$lang['deleted']               = 'strika';
$lang['created']               = 'stovna';
$lang['restored']              = 'gomul útgáva endurstovna (%s)';
$lang['summary']               = 'Samandráttur';
$lang['mail_newpage']          = 'skjal skoyta uppí:';
$lang['mail_changed']          = 'skjal broytt:';
$lang['qb_bold']               = 'Feit';
$lang['qb_italic']             = 'Skák';
$lang['qb_underl']             = 'Undurstrika';
$lang['qb_code']               = 'Skrivimaskinu tekstur';
$lang['qb_strike']             = 'Gjøgnumstrika';
$lang['qb_h1']                 = 'Stig 1 yvirskrift';
$lang['qb_h2']                 = 'Stig 2 yvirskrift';
$lang['qb_h3']                 = 'Stig 3 yvirskrift';
$lang['qb_h4']                 = 'Stig 4 yvirskrift';
$lang['qb_h5']                 = 'Stig 5 yvirskrift';
$lang['qb_link']               = 'Innanhýsis slóð';
$lang['qb_extlink']            = 'Útvortis slóð';
$lang['qb_hr']                 = 'Vatnrætt linja';
$lang['qb_ol']                 = 'Talmerktur listi';
$lang['qb_ul']                 = 'Ótalmerktur listi';
$lang['qb_media']              = 'Leggja myndir og aðrar fílur afturat';
$lang['qb_sig']                = 'Set inn undirskrift';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Sertekn';
$lang['admin_register']        = 'Upprætta nýggjan brúkara';
$lang['metaedit']              = 'Rætta metadáta';
$lang['metasaveerr']           = 'Brek við skriving av metadáta';
$lang['metasaveok']            = 'Metadáta goymt';
$lang['img_backto']            = 'Aftur til';
$lang['img_title']             = 'Heitið';
$lang['img_caption']           = 'Myndatekstur';
$lang['img_date']              = 'Dato';
$lang['img_fname']             = 'Fílunavn';
$lang['img_fsize']             = 'Stødd';
$lang['img_artist']            = 'Myndafólk';
$lang['img_copyr']             = 'Upphavsrættur';
$lang['img_format']            = 'Snið';
$lang['img_camera']            = 'Fototól';
$lang['img_keywords']          = 'Evnisorð';
$lang['authtempfail']          = 'Validering av brúkara virkar fyribils ikki. Um hetta er varandi, fá so samband við umboðsstjóran á hesi wiki.';
